@@ -3,8 +3,20 @@
 import random
 import tempfile
 import os
+import sys
 from textwrap import dedent
 import osmium
+from datetime import datetime
+
+if sys.version_info[0] == 3:
+    from datetime import timezone
+
+    def mkdate(*args):
+        return datetime(*args, tzinfo=timezone.utc)
+else:
+    def mkdate(*args):
+        return datetime(*args)
+
 
 def _complete_object(o):
     """Takes a hash with an incomplete OSM object description and returns a
@@ -102,6 +114,8 @@ def osmobj(kind, **args):
     ret['type'] = kind
     return ret
 
+def check_repr(o):
+    return not str(o).startswith('<') and not repr(o).startswith('<')
 
 class HandlerTestBase:
 
@@ -115,7 +129,29 @@ class HandlerTestBase:
             fn = create_opl_file(self.data)
 
         try:
-            self.Handler().apply_file(fn, self.apply_locations, self.apply_idx)
+            self.handler = self.Handler()
+            self.handler.apply_file(fn, self.apply_locations, self.apply_idx)
         finally:
             os.remove(fn)
 
+        if hasattr(self, "check_result"):
+            self.check_result()
+
+
+class CountingHandler(osmium.SimpleHandler):
+
+    def __init__(self):
+        super(CountingHandler, self).__init__()
+        self.counts = [0, 0, 0, 0]
+
+    def node(self, _):
+        self.counts[0] += 1
+
+    def way(self, _):
+        self.counts[1] += 1
+
+    def relation(self, _):
+        self.counts[2] += 1
+
+    def area(self, _):
+        self.counts[3] += 1
